/*------------------------------------------------------------------------
 |  FILE            TestCommon.java
 |  PART OF
 |  WRITTEN BY      Sverre H. Huseby <shh@thathost.com>
 +----------------------------------------------------------------------*/

package test;

import java.util.*;
import java.io.*;

import java.net.URL;
import java.sql.*;

/**
 *
 * @author   Sverre H. Huseby
 *           &lt;<A HREF="mailto:shh@thathost.com">shh@thathost.com</A>&gt;
 * @version  $Id: TestCommon.java,v 1.2 2002/02/05 23:08:16 sverrehu Exp $
 */
public class TestCommon {
/*-----------------------------------------------------------------------+
|  INHERITANTS' INTERFACE                                                |
+-----------------------------------------------------------------------*/
    protected Connection con;

    protected final void fullGarbageCollection() {
        Runtime rt;
        long    isFree, wasFree;

        rt = Runtime.getRuntime();
        isFree = rt.freeMemory();

        do {
            wasFree = isFree;
            rt.gc();
            isFree = rt.freeMemory();
        } while (isFree > wasFree);
        rt.runFinalization();
    }

    protected final void connect(String driver, String url) {
        try {
            Class.forName(driver);
        } catch (ClassNotFoundException e) {
            System.err.println("class not found error: " + e.getMessage());
            System.exit(1);
        }
        try {
            con = DriverManager.getConnection(url,
                                              "sverrehu", "3142");
        } catch (SQLException e) {
            System.err.println("connect error: " + e.getMessage());
            e.printStackTrace(System.err);
            System.exit(1);
        }
    }

    protected final void close() {
        if (con == null)
            return;
        try {
            con.close();
        } catch (SQLException e) {
            System.err.println("close error: " + e.getMessage());
        }
    }

    protected final int execute(String cmd) {
        int               q, ret = 0, numCols;
        String            s;
        Statement         stmt;
        ResultSet         rs;
        ResultSetMetaData meta;

        try {
            stmt = con.createStatement();
            rs = stmt.executeQuery(cmd);
            meta = rs.getMetaData();
            numCols = meta.getColumnCount();
            while (rs.next()) {
                for (q = 1; q <= numCols; q++) {
                    s = rs.getString(q);
                }
                ++ret;
            }
            rs.close();
            stmt.close();
        } catch (SQLException e) {
            System.err.println("execute error: " + e.getMessage());
            e.printStackTrace(System.err);
        }
        return ret;
    }

    protected final long getMedian(long[] arr) {
        int  q, w, extremeIdx;
        int  start = 0, end = arr.length - 1;
        long tmp, extreme, ret;

        for (q = end; q >= start; q--) {
            extremeIdx = q;
            extreme = arr[q];
            for (w = q - 1; w >= start; w--)
                if (arr[w] > extreme) {
                    extremeIdx = w;
                    extreme = arr[w];
                }
            tmp = arr[q];
            arr[q] = arr[extremeIdx];
            arr[extremeIdx] = tmp;
        }

        if ((arr.length & 1) == 0) {
            ret = (arr[arr.length / 2] + arr[arr.length / 2 + 1]) / 2;
        } else
            ret = arr[arr.length / 2];
        return ret;
    }

}
